from ..utils.core_utils import CoreUtil as CoreUtil
from .config import GeneratorConfig as GeneratorConfig
from .meta_model import ColumnMetaModel as ColumnMetaModel, GenerateMetaModel as GenerateMetaModel, InitFileSchemaModel as InitFileSchemaModel
from _typeshed import Incomplete

class TemplateBuilder:
    output: Incomplete
    def __init__(self, *, config: GeneratorConfig) -> None: ...
    @classmethod
    def format_column(cls, column: ColumnMetaModel) -> str: ...
    def generate_init_file(self, *, schema_names, template_name: str): ...
    def generate_init_file_for_schema_router(self, *, meta_model: InitFileSchemaModel, template_name: str): ...
    def generate_code(self, *, meta_model: GenerateMetaModel, template_name: str, child_path=...): ...
    def get_generate_meta_model(self, *, table_name, schema_name) -> GenerateMetaModel: ...
    def get_schema_init_file_meta_model(self, *, schema_name, imports, routers) -> InitFileSchemaModel: ...
    def get_table_names(self, *, schema_name): ...
    def get_schema_names(self): ...



from ..services.auth_service import AuthService as AuthService
from enum import Enum
from fastapi import APIRouter, params as params
from typing import Sequence

class AuthRouter(APIRouter):
    def __init__(self, *, prefix: str, tags: list[str | Enum] | None = None, dependencies: Sequence[params.Depends] | None = None) -> None: ...



from ..entity_table.dept import Dept as Dept, DeptCreate as DeptCreate, DeptResponse as DeptResponse, DeptUpdate as DeptUpdate
from _typeshed import Incomplete
from shudaodao_core import AsyncSession as AsyncSession, QueryRequest as QueryRequest

Dept_Router: Incomplete

async def dept_create(*, db: AsyncSession = ..., create_model: DeptCreate): ...
async def dept_read(*, db: AsyncSession = ..., primary_id: int): ...
async def dept_update(*, db: AsyncSession = ..., primary_id: int, model_update: DeptUpdate): ...
async def dept_delete(*, db: AsyncSession = ..., primary_id: int): ...
async def dept_query(*, db: AsyncSession = ..., query: QueryRequest): ...



from ..exception.service_exception import DataNotFoundException as DataNotFoundException
from ..schemas.query_request import QueryRequest as QueryRequest
from ..type.var import SQLModelCreate as SQLModelCreate, SQLModelDB as SQLModelDB, SQLModelResponse as SQLModelResponse, SQLModelUpdate as SQLModelUpdate
from .query_builder import QueryBuilder as QueryBuilder
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession
from typing import Any

class DataService:
    @classmethod
    def db_insert(cls, db: AsyncSession, *, db_model_class: type[SQLModelDB], create_model: SQLModelCreate | dict[str, Any]) -> SQLModelDB: ...
    @classmethod
    async def create(cls, db: AsyncSession, *, db_model_class: type[SQLModelDB], create_model: SQLModelCreate | dict[str, Any], response_class: type[SQLModelResponse] = None, auto_commit: bool = True) -> SQLModelDB | SQLModelResponse: ...
    @classmethod
    async def db_get(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB]) -> SQLModelDB | None: ...
    @classmethod
    async def read(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], response_model: type[SQLModelResponse] = None) -> SQLModelDB | SQLModelResponse: ...
    @classmethod
    async def db_update(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], update_model: SQLModelUpdate | dict[str, Any]) -> SQLModelDB | None: ...
    @classmethod
    async def update(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], update_model: SQLModelUpdate | dict[str, Any], response_model: type[SQLModelResponse] = None, auto_commit: bool = True) -> SQLModelDB | SQLModelResponse: ...
    @classmethod
    async def db_delete(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB]) -> bool: ...
    @classmethod
    async def delete(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], auto_commit: bool = True) -> bool: ...
    @classmethod
    async def query(cls, db: AsyncSession, query: QueryRequest, *, model_class: type[SQLModelDB]): ...
    @classmethod
    async def query_first(cls, db: AsyncSession, query: QueryRequest, *, model_class: type[SQLModelDB]): ...
    @classmethod
    def get_primary_key_name(cls, model_class: type[SQLModelDB]) -> str | list[str] | None: ...



from dataclasses import dataclass
from sqlalchemy import inspect as inspect
from typing import Any

@dataclass
class ColumnMetaModel:
    name: str
    type: Any
    nullable: bool
    default: Any
    is_primary: bool
    autoincrement: bool
    comment: str = ...
    max_length: int | None = ...
    @property
    def field_constraints(self) -> list[str]: ...

@dataclass
class GenerateMetaModel:
    inspector = ...
    schema_name = ...
    router_path = ...
    table_name = ...
    file_name = ...
    class_name = ...
    columns: list[ColumnMetaModel] = ...
    table_comment: str = ...
    generated_date: str = ...
    entity_imports: list[str] = ...
    table_args: str = ...
    def __init__(self, *, inspector: inspect, table_name, schema_name, output_entity_schema, router_path) -> None: ...

@dataclass
class InitFileTableModel:
    import_str: str
    router_str: str

@dataclass
class InitFileSchemaModel:
    router_path: str = ...
    imports: list[str] = ...
    routers: list[str] = ...
    def __init__(self, *, imports, routers, router_path) -> None: ...

class InitFileGenerateModel:
    imports: list[str]



from ..utils.response_utils import ResponseUtil as ResponseUtil
from .service_exception import AuthException as AuthException, ShudaodaoException as ShudaodaoException
from fastapi import FastAPI as FastAPI, Request as Request

def register_exception_handlers(app: FastAPI): ...



from ..schemas.query_request import Condition as Condition, QueryLogicOperation as QueryLogicOperation, QueryRequest as QueryRequest, QuerySimpleCondition as QuerySimpleCondition
from sqlmodel import SQLModel as SQLModel
from typing import Any

class QueryBuilder:
    @classmethod
    def build_result(cls, selected_fields, results): ...
    @staticmethod
    def build_order_by(query: QueryRequest, model_class: type[SQLModel]) -> Any: ...
    @staticmethod
    def build_fields(query: QueryRequest, model_class: type[SQLModel]) -> Any: ...
    @staticmethod
    def build_where(condition: Condition, model_class: type[SQLModel]) -> Any: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/18 下午7:43
# @Desc     ：

from typing import Optional, Any

from pydantic import BaseModel


class BaseResponse(BaseModel):
    success: bool = True
    code: int = 200
    name: Optional[str] = None
    message: str = ""


class DataResponse(BaseResponse):
    data: Optional[Any] = None


class ErrorResponse(BaseResponse):
    error: Optional[Any] = None



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/28 下午2:02
# @Desc     ：

from pydantic import BaseModel


class PagingElement(BaseModel):
    items: list
    total: int
    page: int
    size: int
    pages: int


class ListElement(BaseModel):
    items: list


class SelectElement(BaseModel):
    items: list



import abc
from ..config.app_config import AppConfig as AppConfig
from ..controller.auth import Auth_Controller as Auth_Controller
from ..controller.default import Default_Controller as Default_Controller
from ..exception.register_handlers import register_exception_handlers as register_exception_handlers
from ..logger.logging_ import logging as logging
from ..utils.core_utils import CoreUtil as CoreUtil
from .auth_router import AuthRouter as AuthRouter
from _typeshed import Incomplete
from abc import ABC, abstractmethod

class BaseApplication(ABC, metaclass=abc.ABCMeta):
    app: Incomplete
    def __init__(self) -> None: ...
    @abstractmethod
    def add_middleware(self) -> None: ...
    @abstractmethod
    def add_router(self) -> None: ...
    def include_router(self, controllers) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/7/20 下午1:20
# @Desc     ：

from typing import Literal, Optional, List

from pydantic import Field, BaseModel

from .context import ContextConfigSetting
from .models import ModelCollectionConfigSetting
from .snowflake import SnowflakeConfigSetting
from .storage import StorageConfigSetting
from .webapp import FastAPIConfigSetting


class EnvironmentConfigSetting(BaseModel):
    model: Literal["dev", "prod"] = Field(..., description="环境配置")
    logging_level: str = Field("debug", description="日志级别")
    show_merge_yaml: bool = Field(True, description="显示合并yaml")

    @property
    def is_prod(self) -> bool:
        return self.model == "prod"

    @property
    def model_desc(self) -> str:
        return "开发环境" if self.model == "dev" else "生产环境"

    @property
    def logging_level_desc(self) -> str:
        if self.logging_level == "debug":
            return "调试"
        elif self.logging_level == "info":
            return "提醒"
        elif self.logging_level == "warning":
            return "警告"
        elif self.logging_level == "error":
            return "错误"
        else:
            raise ValueError(f"Unknown logging level: {self.logging_level}")


class AppConfigSetting(BaseModel):
    environment: EnvironmentConfigSetting = Field(default_factory=EnvironmentConfigSetting, description="环境配置")
    webapp: FastAPIConfigSetting = Field(default_factory=FastAPIConfigSetting, description="FastAPI启动")
    generate_snowflake: SnowflakeConfigSetting = Field(None, description="雪花算法ID生成配置")
    storage: Optional[StorageConfigSetting] = Field(None, description="存储配置")
    context: Optional[List[ContextConfigSetting]] = Field(None, description="上下文配置")
    models: Optional[ModelCollectionConfigSetting] = Field(None, description="模型配置")
